//
//  AiBrushBleManager.h
//  AiBrushBleSDK
//
//  Created by iot_user on 2019/7/3.
//  Copyright © 2019 IOT. All rights reserved.
//

#import <Foundation/Foundation.h>
#import "AiBrushPeripheralModel.h"
#import "AiBrushBleHeader.h"
#import "AiBrushWorkStateModel.h"
#import "AiBrushBatteryStateModel.h"
#import "AiBrushWorkDataModel.h"
#import "AiBrushGsensorModel.h"
#import "AiBrushStrengthModel.h"


NS_ASSUME_NONNULL_BEGIN

@protocol AiBrushBleManagerDelegate <NSObject>

/**
 Callback Bluetooth current status(回调蓝牙当前状态)

 @param state Bluetooth status(蓝牙状态)
 */
-(void)brushBleManagerUpdateBleState:(AiBrushBleState)state;

/**
 Callback to all peripherals scanned(回调扫描到的所有外设)

 @param peripheralList Peripheral list(外设列表)
 */
-(void)brushBleManagerScanedPeripherals:(NSArray<AiBrushPeripheralModel *> *)peripheralList;

/**
 Reporting setup mode results(上报设置模式结果)

 @param result (结果)
 */
-(void)brushBleManagerReceiveSetModeResult:(AiBrushSetModeResult)result;

/**
 Reporting work status(上报工作状态)

 @param model Working state model(工作状态模型)
 */
-(void)brushBleManagerReceiveWorkState:(AiBrushWorkStateModel *)model;

/**
 Report power status(上报电源状态)

 @param model Power state model(电源状态模型)
 */
-(void)brushBleManagerReceiveBatteryStateModel:(AiBrushBatteryStateModel *)model;

/**
 Confirm receipt of disconnected Bluetooth connection request(确认收到断开蓝牙连接请求)
 */
-(void)brushBleManagerReceiveDisconnectResult;

/**
 Reporting device time(上报设备时间)

 @param time (时间)
 */
-(void)brushBleManagerReceiveSystemTime:(int)time;

/**
 Return to set device time results(返回设置设备时间结果)

 @param result (结果)
 1:Set device time to succeed(设置设备时间成功)
 2:Setting device time failed(设置设备时间失败)
 */
-(void)brushBleManagerReceiveSetTimeResult:(int)result;

/**
 Returns the number of historical data(返回历史数据条数)

 @param count Total historical data(历史数据总数)
 */
-(void)brushBleManagerReceiveHistoryDataCount:(int)count;

/**
 Cancel the reading of historical data operation results(取消读取历史数据操作结果)

 @param result (结果)
 1:Cancel the read successfully(取消读取成功)
 2:Cancel read failed(取消读取失败)
 */
-(void)brushBleManagerReceiveCancelReadHistoryDataResult:(int)result;

/**
 Delete historical data(删除历史数据)

 @param result (结果)
 1:successfully(删除成功)
 2:failed(删除失败)
 */
-(void)brushBleManagerReceiveDeleteHistoryDataResult:(int)result;

/**
 Callback historical data(回调历史数据)

 @param model Historical data model(历史数据模型)
 */
-(void)brushBleManagerReceiveHistoryDataModel:(AiBrushWorkDataModel *)model;

/**
 Callback work data(回调工作数据)

 @param model Data model(数据模型)
 */
-(void)brushBleManagerReceiveWorkDataModel:(AiBrushWorkDataModel *)model;

/**
 Reporting Sensor data(上报 Sensor 数据)

 @param model (数据模型)
 */
-(void)brushBleManagerReceiveGsensorDataModel:(AiBrushGsensorModel *)model;

/**
 Reporting strength data(上报力度相关数据)

 @param model (数据模型)
 */
-(void)brushBleManagerReceiveStrengthDataModel:(AiBrushStrengthModel *)model;

/**
 Report button to confirm the app connection status
   1----Key action confirmation App connection is valid, 2----App requires button confirmation, 3----App is valid without key confirmation(上报按键确认 App 连接状态
 1----按键动作确认 App 连接有效，2----App 需要按键确认，3----App 有效不需要按键确认)
 @param state (连接状态)
 */
-(void)brushBleManagerReceiveConnectState:(int)state;
/**
 Callback brushing mode gear(回调刷牙模式档位)
 
 @param oneGear (一级档位)
 @param twoGear (二级档位)
 */
- (void)brushBleManagerReturnOneGearMode:(NSArray<NSNumber *> *)oneGear twoGearMode:(NSArray<NSNumber *> *)twoGear;

/**
 Set DID results(设置DID结果)
 @param result (结果)
 YES:successfully(成功)
 NO：failed(失败)
 */
-(void)brushBleManagerReturnSetDIDResult:(BOOL)result;

/**
 Set the Name result(设置Name结果)
 @param result (结果)
 YES:successfully(成功)
 NO：failed(失败)
 */
-(void)brushBleManagerReturnSetNameResult:(BOOL)result;

/**
 Return to OTA upgrade progress(返回OTA升级进度)

 @param progress (升级进度)
 */
-(void)brushBleManagerReturnOTAUpdateProgress:(double)progress;

/**
 Return OTA upgrade results(返回OTA升级结果)

 @param result (结果)
 */
-(void)brushBleManagerOTAUpdateResult:(BOOL)result;
@end


@interface AiBrushBleManager : NSObject
//
@property (nonatomic, weak) id<AiBrushBleManagerDelegate> delegate;
//Bluetooth is available(蓝牙是否可用)
@property (nonatomic, assign, readonly) BOOL isOn;
//Bluetooth status(蓝牙状态)
@property (nonatomic, assign, readonly) AiBrushBleState state;
//当前是否在工作
@property (nonatomic, assign,readonly) BOOL isWorking;

//Version(版本号)
@property (nonatomic, copy ,readonly) NSString *version;
//Toothbrush version type(牙刷版本类型)
@property (nonatomic, assign, readonly) AiBrushVersionType versionType;
//Bluetooth is connected(蓝牙是否连接)
@property (nonatomic, assign, readonly) BOOL isConnect;
//First gear position of the toothbrush(牙刷的一级档位)
@property (nonatomic, copy,readonly) NSArray<NSNumber *> *oneGearArray;
//Second gear of the toothbrush(牙刷的二级档位)
@property (nonatomic, copy,readonly) NSArray<NSNumber *> *twoGearArray;



+(void)setAppKey:(NSString *)key appSecret:(NSString *)secret;

//
+(instancetype)shareManager;
//Get the version number(获取版本号)
-(NSString *)sdkVersion;
//Start scanning(开始扫描)
-(void)startScan;
//Stop scanning(停止扫描)
-(void)stopScan;
//Connecting device(连接设备)
-(void)connectPeripheral:(CBPeripheral *)peripheral;

-(void)connectPeripheralWithMac:(NSString *)mac;
//Disconnect(断开连接)
-(void)disconnectPeripheral;

/**
 Set brushing mode
   For details on the mode settings, please see the agreement description.(设置刷牙模式
 关于模式设置的详细资料，请查看协议说明)
 @param byte Must pass 4 bytes of data(必须传4个byte的数据)
 */
-(void)setBrushModeWithByte:(Byte[_Nonnull])byte;

/**
 Query work status(查询工作状态)
 */
-(void)queryWorkState;

/**
 Query power status(查询电源状态)
 */
-(void)queryBatteryState;

/**
 Switching work status(切换工作状态)
 */
-(void)changeWorkState;


/**
 Query device time(查询设备时间)
 */
-(void)querySystemTime;


/**
 Set system time(设置系统时间)
 */
-(void)setSystemTime;


/**
 Reading historical data(读取历史数据)
 */
-(void)queryHistoryData;


/**
 Cancel reading historical data(取消读取历史数据)
 */
-(void)cancelReadHistoryData;


/**
 Delete historical data(删除历史数据)
 */
-(void)deleteHistoryData;
//Request gear information(请求档位信息)
-(void)queryGear;

//Set theid:0~65535, please refer to "蓝牙电动牙刷厂商型号列表"(设置did：0~65535,请参考《蓝牙电动牙刷厂商型号列表》)
-(void)setDID:(int)did;

//Set the Bluetooth name(设置蓝牙名称)
-(void)setName:(NSString *)name;

/**
 OTA upgrade(OTA升级)

 @param fileStr file path(文件路径)
 */
- (void)OTAUpdate:(NSURL *)fileStr;

/**
 Restart the device after the upgrade is successful.(升级成功后重启设备)
 */
- (void)rebootDevice;
@end

NS_ASSUME_NONNULL_END
