//
//  ViewController.m
//  AiBrushBleSDK
//
//  Created by iot_user on 2019/7/3.
//  Copyright © 2019 IOT. All rights reserved.
//

#import "ViewController.h"

#import <AiBrushBleSDK/AiBrushBleManager.h>
#import "AppTool.h"

@interface ViewController ()<AiBrushBleManagerDelegate,UITableViewDelegate,UITableViewDataSource>
@property (nonatomic, strong) UITableView *tableView;
@property (nonatomic, copy) NSArray<AiBrushPeripheralModel *> *devices;
@property (nonatomic, strong) UIView *headerView;
@property (nonatomic, strong) UIView *barView;
@property (nonatomic, strong) UIView *footerView;



@end

@implementation ViewController

- (void)viewDidLoad {
    [super viewDidLoad];
    [AiBrushBleManager shareManager].delegate = self;
    [[AiBrushBleManager shareManager] startScan];
    //
    [self.view addSubview:self.barView];
    //
    [self.view addSubview:self.tableView];
    
}
#pragma mark ============ AiBrushBleManagerDelegate ==============
-(void)brushBleManagerOTAUpdateResult:(BOOL)result{
    NSLog(@"brushBleManagerOTAUpdateResult = %d",result);
}
-(void)brushBleManagerReturnOTAUpdateProgress:(double)progress{
    NSLog(@"brushBleManagerReturnOTAUpdateProgress = %f",progress);
}
-(void)brushBleManagerReturnSetDIDResult:(BOOL)result{
    NSLog(@"brushBleManagerReturnSetDIDResult = %d",result);
}
-(void)brushBleManagerReturnSetNameResult:(BOOL)result{
    NSLog(@"brushBleManagerReturnSetNameResult = %d",result);
}
-(void)brushBleManagerReturnOneGearMode:(NSArray<NSNumber *> *)oneGear twoGearMode:(NSArray<NSNumber *> *)twoGear{
    NSLog(@"oneGear = %@-----twoGear = %@",oneGear,twoGear);
}
-(void)brushBleManagerReceiveConnectState:(int)state{
    NSLog(@"brushBleManagerReceiveConnectState = %d",state);
    if (state == 1 || state == 3) {
        //获取第档位信息
        [[AiBrushBleManager shareManager] queryGear];
    }

}
-(void)brushBleManagerReceiveStrengthDataModel:(AiBrushStrengthModel *)model{
    NSLog(@"brushBleManagerReceiveStrengthDataModel = %@",model.description);
}
-(void)brushBleManagerReceiveGsensorDataModel:(AiBrushGsensorModel *)model{
    NSLog(@"x=%d---y=%d---z=%d---xChange=%d---yChange=%d---zChange=%d",model.x,model.y,model.z,model.xChange,model.yChange,model.zChange);
}
-(void)brushBleManagerReceiveWorkDataModel:(AiBrushWorkDataModel *)model{
    NSLog(@"dataNumber:%d---leftTime:%d---brushMode:%lu---duty:%d---workTime:%d---startTime:%d---workDuration:%d",model.dataNumber,model.leftTime,(unsigned long)model.brushMode,model.duty,model.workTime,model.startTime,model.workDuration);
}
-(void)brushBleManagerReceiveHistoryDataModel:(AiBrushWorkDataModel *)model{
    NSLog(@"dataNumber:%d---leftTime:%d---brushMode:%lu---duty:%d---workTime:%d---startTime:%d---workDuration:%d",model.dataNumber,model.leftTime,(unsigned long)model.brushMode,model.duty,model.workTime,model.startTime,model.workDuration);
}
-(void)brushBleManagerReceiveHistoryDataCount:(int)count{
    NSLog(@"brushBleManagerReceiveHistoryDataCount = %d",count);
}
-(void)brushBleManagerReceiveSetTimeResult:(int)result{
    NSLog(@"brushBleManagerReceiveSetTimeResult = %d",result);
}
-(void)brushBleManagerReceiveSystemTime:(int)time{
    NSLog(@"brushBleManagerReceiveSystemTime = %d",time);
}
-(void)brushBleManagerReceiveDisconnectResult{
    NSLog(@"断开连接");
    
}
-(void)brushBleManagerReceiveBatteryStateModel:(AiBrushBatteryStateModel *)model{
    NSLog(@"brushBleManagerReceiveBatteryStateModel = voltage:%d--peakCurrent:%d--percentCharge:%d",model.voltage,model.peakCurrent,model.percentCharge);
}
-(void)brushBleManagerReceiveWorkState:(AiBrushWorkStateModel *)model{
    NSLog(@"brushBleManagerReceiveWorkState = workState:%d--brushMode:%lu--modeOrFrequency:%d--workTime:%d--duty:%d",model.workState,(unsigned long)model.brushMode,model.modeOrFrequency,model.workTime,model.duty);
}
-(void)brushBleManagerReceiveSetModeResult:(AiBrushSetModeResult)result{
    NSLog(@"SetModeResult = %lu",(unsigned long)result);
}
-(void)brushBleManagerUpdateBleState:(AiBrushBleState)state{
    if (state == AiBrushBleStateAvailable) {
        self.tableView.tableHeaderView = [UIView new];
        self.tableView.tableFooterView = [UIView new];
        [self.tableView reloadData];
    }else if (state == AiBrushBleStateUnavailable){
        self.devices = nil;
        self.tableView.tableHeaderView = self.headerView;
        self.tableView.tableFooterView = [UIView new];
        [self.tableView reloadData];
    }else if (state == AiBrushBleStateDidUpdateCharacteristicState){
        self.devices = nil;
        self.tableView.tableFooterView = self.footerView;
        self.tableView.tableHeaderView = [UIView new];
        [self.tableView reloadData];
    }else if (state == AiBrushBleStateConnectFail || state == AiBrushBleStateDidDisconnect){
        [[AiBrushBleManager shareManager] startScan];
        self.tableView.tableHeaderView = [UIView new];
        self.tableView.tableFooterView = [UIView new];
        self.devices = nil;
        [self.tableView reloadData];
    }
}
-(void)brushBleManagerScanedPeripherals:(NSArray<AiBrushPeripheralModel *> *)peripheralList{
    NSLog(@"brushBleManagerScanedPeripherals = %ld",peripheralList.count);
    self.devices = peripheralList;
    [self.tableView reloadData];
}
#pragma mark ============ tableView代理  ==============
-(NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section{
    return self.devices.count;
}
-(CGFloat)tableView:(UITableView *)tableView heightForRowAtIndexPath:(NSIndexPath *)indexPath{
    return 50;
}
-(UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath{
    static NSString *cellID = @"cellID";
    UITableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:cellID];
    if (!cell) {
        cell = [[UITableViewCell alloc] initWithStyle:(UITableViewCellStyleValue1) reuseIdentifier:cellID];
    }
    AiBrushPeripheralModel *model = self.devices[indexPath.row];
    cell.textLabel.text = model.peripheralName;
    cell.detailTextLabel.text = model.macAddress;
    return cell;
}
-(void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath{
    AiBrushPeripheralModel *model = self.devices[indexPath.row];
    [[AiBrushBleManager shareManager] connectPeripheral:model.peripheral];
}
- (UITableView *)tableView{
    if (_tableView == nil) {
        _tableView = [[UITableView alloc]initWithFrame:CGRectMake(0, CGRectGetMaxY(self.barView.frame), self.view.frame.size.width, self.view.frame.size.height-self.barView.frame.size.height)];
        _tableView.delegate = self;
        _tableView.dataSource = self;
    }
    return _tableView;
}
-(UIView *)headerView{
    if (_headerView == nil) {
        _headerView = [[UIView alloc] initWithFrame:CGRectMake(0, 0, self.tableView.frame.size.width, self.tableView.frame.size.height)];
        UILabel *lable = [[UILabel alloc] initWithFrame:CGRectMake(0, 0, _headerView.frame.size.width, _headerView.frame.size.height)];
        lable.text = @"请打开蓝牙";
        lable.textColor = [UIColor redColor];
        lable.font = [UIFont systemFontOfSize:35];
        lable.textAlignment = NSTextAlignmentCenter;
        [_headerView addSubview:lable];
    }
    return _headerView;
}
- (UIView *)barView{
    if (_barView == nil) {
        _barView = [[UIView alloc] init];
        _barView.frame = CGRectMake(0, 0, self.view.frame.size.width, 44+TopMargin);
        UILabel *lable = [[UILabel alloc] initWithFrame:CGRectMake(0, 0, _barView.frame.size.width, _barView.frame.size.height)];
        lable.text = @"扫描到的设备";
        lable.textColor = [UIColor blackColor];
        lable.font = [UIFont systemFontOfSize:18];
        lable.textAlignment = NSTextAlignmentCenter;
        [_barView addSubview:lable];
        
    }
    return _barView;
}
-(void)button1Action:(UIButton *)sender{
    [[AiBrushBleManager shareManager] setDID:100];
}
-(void)button2Action:(UIButton *)sender{
    NSArray *titles = @[@"Clean",@"White",@"Massage",@"Sensitive",@"Custom",@"Polish",@"GumCare",@"Refresh",@"Mascare",@"Soft"];
    UIAlertController *alert = [UIAlertController alertControllerWithTitle:@"Pick Mode" message:nil preferredStyle:(UIAlertControllerStyleAlert)];
    for (int i=0; i<titles.count; i++) {
        UIAlertAction *action = [UIAlertAction actionWithTitle:titles[i] style:(UIAlertActionStyleDefault) handler:^(UIAlertAction * _Nonnull action) {
            Byte mode = 0x01;
            if (i==0) {
                mode = 0x01;
            }else if (i==1){
                mode = 0x02;
            }else if (i==2){
                mode = 0x03;
            }else if (i==3){
                mode = 0x04;
            }else if (i==4){
                mode = 0x06;
            }else if (i==5){
                mode = 0x07;
            }else if (i==6){
                mode = 0x08;
            }else if (i==7){
                mode = 0x09;
            }else if (i==8){
                mode = 0x0a;
            }else if (i==9){
                mode = 0x0b;
            }

            [self setBrushMode:mode];
        }];
        [alert addAction:action];
    }
    [self presentViewController:alert animated:YES completion:nil];
}
-(void)setBrushMode:(Byte)mode{
//    Byte b[4] = {0x03,0x00,0x00,0x16};
//
//    [[AiBrushBleManager shareManager] setBrushModeWithByte:b];
    if (mode == 0x06){
        Byte b[4] = {0x06,0x02,0x03,0x16};
        
        [[AiBrushBleManager shareManager] setBrushModeWithByte:b];
    }else{
        if ([[AiBrushBleManager shareManager].oneGearArray containsObject:[NSNumber numberWithChar:mode]]) {
            Byte dataByte[] = {mode,0x00,0x00,0x16};
            [[AiBrushBleManager shareManager] setBrushModeWithByte:dataByte];
        }else{
            if (mode == 0x07 || mode == 0x08 || mode == 0x09 || mode == 0x0A || mode == 0x0B ) {
                if ([AiBrushBleManager shareManager].versionType == AiBrushVersionTypeBY01 || [AiBrushBleManager shareManager].versionType == AiBrushVersionTypeBY02 || [AiBrushBleManager shareManager].versionType == AiBrushVersionTypeBY03 || [AiBrushBleManager shareManager].versionType == AiBrushVersionTypeBY04) {
                    Byte modeIDByte=0x00;
                    if (mode == 0x07) {
                        modeIDByte = 0x01;
                    }else if (mode == 0x08){
                        modeIDByte = 0x02;
                    }else if (mode == 0x09){
                        modeIDByte = 0x03;
                    }else if (mode == 0x0A){
                        modeIDByte = 0x04;
                    }else if (mode == 0x0B){
                        modeIDByte = 0x05;
                    }
                    
                    Byte dataByte[] = {0x05,modeIDByte,0x00,0x16};
                    [[AiBrushBleManager shareManager] setBrushModeWithByte:dataByte];
                }else{
                    Byte dataByte[] = {mode,0x00,0x00,0x16};
                    [[AiBrushBleManager shareManager] setBrushModeWithByte:dataByte];
                }
                
            }else{
                Byte dataByte[] = {mode,0x00,0x00,0x16};
                [[AiBrushBleManager shareManager] setBrushModeWithByte:dataByte];
            }
        }
    }
}
-(void)button3Action:(UIButton *)sender{
    [[AiBrushBleManager shareManager] queryWorkState];
}
-(void)button4Action:(UIButton *)sender{
    [[AiBrushBleManager shareManager] queryBatteryState];
}
-(void)button5Action:(UIButton *)sender{
    [[AiBrushBleManager shareManager] changeWorkState];
}
-(void)button6Action:(UIButton *)sender{
    [[AiBrushBleManager shareManager] disconnectPeripheral];
}
-(void)button7Action:(UIButton *)sender{
    [[AiBrushBleManager shareManager] querySystemTime];
}
-(void)button8Action:(UIButton *)sender{
    [[AiBrushBleManager shareManager] setSystemTime];
}
-(void)button9Action:(UIButton *)sender{
    [[AiBrushBleManager shareManager] queryHistoryData];
}
-(void)button10Action:(UIButton *)sender{
    [[AiBrushBleManager shareManager] setName:@"Elink"];
}
-(void)button11Action:(UIButton *)sender{
    //获取本地img文件
    NSArray *paths = NSSearchPathForDirectoriesInDomains(NSDocumentDirectory, NSUserDomainMask, YES);
    NSString *publicDocumentsDir = [paths objectAtIndex:0];
    
    NSError *error;
    NSFileManager *fm = [NSFileManager defaultManager];
    NSString *currentPath;
    currentPath = [publicDocumentsDir stringByAppendingPathComponent:@"toothbrush_20170115_V1.3.img"];
    
    BOOL isExist = [fm fileExistsAtPath:currentPath];
    if (!isExist) {
        NSString *backUpdapath = [[NSBundle mainBundle] pathForResource:@"toothbrush_20170115_V1.3" ofType:@"img"];
        
        BOOL cp = [fm copyItemAtPath:backUpdapath toPath:currentPath error:&error];
        if (cp) {
            NSLog(@"数据库拷贝成功==%@",currentPath);
            NSURL *url = [NSURL URLWithString:currentPath];
            [[AiBrushBleManager shareManager] OTAUpdate:url];
        }else{
            NSLog(@"数据库拷贝失败");
        }
    }else{
        NSURL *url = [NSURL URLWithString:currentPath];
        [[AiBrushBleManager shareManager] OTAUpdate:url];
    }
}
-(UIView *)footerView{
    if (_footerView == nil) {
        _footerView = [[UIView alloc] initWithFrame:CGRectMake(0, 0, self.tableView.frame.size.width, self.tableView.frame.size.height)];
        //
        UIButton *button1 = [self createButtonWithTitle:@"Set DID" withFrame:CGRectMake(10, 10, 100, 30)];
        [button1 addTarget:self action:@selector(button1Action:) forControlEvents:(UIControlEventTouchUpInside)];
        [_footerView addSubview:button1];
        //
        UIButton *button2 = [self createButtonWithTitle:@"Set Mode" withFrame:CGRectMake(120, 10, 100, 30)];
        [button2 addTarget:self action:@selector(button2Action:) forControlEvents:(UIControlEventTouchUpInside)];
        [_footerView addSubview:button2];
        //
        //
        UIButton *button3 = [self createButtonWithTitle:@"Query work state" withFrame:CGRectMake(240, 10, 100, 30)];
        [button3 addTarget:self action:@selector(button3Action:) forControlEvents:(UIControlEventTouchUpInside)];
        [_footerView addSubview:button3];
        //
        UIButton *button4 = [self createButtonWithTitle:@"Query battery state" withFrame:CGRectMake(10, 50, 100, 30)];
        [button4 addTarget:self action:@selector(button4Action:) forControlEvents:(UIControlEventTouchUpInside)];
        [_footerView addSubview:button4];
        //
        UIButton *button5 = [self createButtonWithTitle:@"Switch Work State" withFrame:CGRectMake(120, 50, 100, 30)];
        [button5 addTarget:self action:@selector(button5Action:) forControlEvents:(UIControlEventTouchUpInside)];
        [_footerView addSubview:button5];
        //
        UIButton *button6 = [self createButtonWithTitle:@"Disconnect" withFrame:CGRectMake(240, 50, 100, 30)];
        [button6 addTarget:self action:@selector(button6Action:) forControlEvents:(UIControlEventTouchUpInside)];
        [_footerView addSubview:button6];
        //
        UIButton *button7 = [self createButtonWithTitle:@"Query system time" withFrame:CGRectMake(10, 90, 100, 30)];
        [button7 addTarget:self action:@selector(button7Action:) forControlEvents:(UIControlEventTouchUpInside)];
        [_footerView addSubview:button7];
        //
        UIButton *button8 = [self createButtonWithTitle:@"Set system time" withFrame:CGRectMake(120, 90, 100, 30)];
        [button8 addTarget:self action:@selector(button8Action:) forControlEvents:(UIControlEventTouchUpInside)];
        [_footerView addSubview:button8];
        //
        UIButton *button9 = [self createButtonWithTitle:@"Query History Count" withFrame:CGRectMake(240, 90, 100, 30)];
        [button9 addTarget:self action:@selector(button9Action:) forControlEvents:(UIControlEventTouchUpInside)];
        [_footerView addSubview:button9];
        //
        //
        UIButton *button10 = [self createButtonWithTitle:@"Set Name" withFrame:CGRectMake(10, 130, 100, 30)];
        [button10 addTarget:self action:@selector(button10Action:) forControlEvents:(UIControlEventTouchUpInside)];
        [_footerView addSubview:button10];
        //
        UIButton *button11 = [self createButtonWithTitle:@"OTA Update" withFrame:CGRectMake(120, 130, 100, 30)];
        [button11 addTarget:self action:@selector(button11Action:) forControlEvents:(UIControlEventTouchUpInside)];
        [_footerView addSubview:button11];
    }
    return _footerView;
}
-(UIButton *)createButtonWithTitle:(NSString *)title withFrame:(CGRect)frame{
    UIButton *button = [UIButton buttonWithType:(UIButtonTypeCustom)];
    button.frame = frame;
    [button setTitle:title forState:(UIControlStateNormal)];
    [button setTitleColor:[UIColor blackColor] forState:(UIControlStateNormal)];
    button.titleLabel.font = [UIFont systemFontOfSize:15];
    button.backgroundColor = [UIColor redColor];
    button.titleLabel.adjustsFontSizeToFitWidth = YES;
    button.titleLabel.numberOfLines=2;
    button.titleLabel.textAlignment = NSTextAlignmentCenter;
    return button;
}
@end
